/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Diese Datei: beispiele.sas
     Dateiformat: Dos\Windows
     Zeichensatz: Windows-1252
     Download: 
     https://www.gesis.org/missy/files/documents/MZ/misc/TR_10-03_SAS.zip
SAS 9.4 for Windows
Version: 10/2019
 
SAS-Syntax zur Varianzschtzung fr Mikrozensus Scientific Use Files ab 2005 
- hier am Beispiel MZ 2015 
  Datenbeschreibung, siehe https://www.gesis.org/missy/metadata/MZ/2015/

Beispiele:
1 Designbasierte Schtzung des Gesamtwertes Zahl der Erwerbslosen
2 Schtzung des Gesamtwertes mit gebundener Hochrechnung (Regressionsschtzung) 
3 Schtzung der Erwerbslosenquote mit Designgewichtung
4 Schtzung der Erwerbslosenquote mit gebundener Hochrechnung (Regressionsschtzung) 
 
Schimpl-Neimanns, Bernhard: Varianzschtzung fr Mikrozensus Scientific Use 
  Files ab 2005. GESIS-Technical Report Nr. 2010/03. Mannheim: GESIS.
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2010/TechnicalReport_10-03.pdf
berarbeitete Fassung verffentlicht als:
Schimpl-Neimanns, Bernhard (2011): Schtzung des Stichprobenfehlers in 
  Mikrozensus Scientific Use Files ab 2005, AStA Wirtschafts- und 
  Sozialstatistisches Archiv 5 (1): 19-38. DOI: 10.1007/s11943-011-0092-4. 
 
nderungen gegenber frheren Versionen:
- Syntax vereinfacht
- Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale bercksichtigt
  nur Bevlkerung am Hauptwohnsitz
* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -  */

libname library '<Arbeitsverzeichnis>' ;
libname mz '<Arbeitsverzeichnis>' ;

options nofmterr;
options compress = binary;
run;

/* Beispiel 1: Designbasierte Schtzung des Gesamtwertes 
            Zahl der Erwerbslosen */

/* Variablenauswahl Scientific Use Files Mikrozensus 2015 */
data temp;
  set mz.mz2015 (keep = 
    EF1	  /* Bundesland */
    EF3	  /* Nr. des Auswahlbezirks (systemfrei) */
    EF4	  /* Nr. des Haushalts im Auswahlbezirk (systemfrei) */
    EF5a  /* Nr. der Person im Haushalt */
    EF5b  /* Jahresberhang aus dem Vorjahr */
    EF12  /* Berichtsquartal */
    EF29  /* Erwerbstyp */
    EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz */
    EF31  /* Bevlkerung: Privathaushalte */
    EF44  /* Alter */
    EF46  /* Geschlecht */
    EF117 /* Stellung im Beruf */
    EF369 /* 1. ausl. Staatsangehrigkeit */
    EF371 /* Staatsangehrigkeit typisiert */
    EF570 /* Gebudegrenklasse */
    /* EF951 Standardhochrechnungsfaktor Quartal (in 1000) */
    EF952 /* Standardhochrechnungsfaktor Jahr (in 1000) */ );

  * Fortlaufende Personennummer (Satznr. File);
  satznr = _n_ ;

  /* Schichtung: Quartal (ef12) x Land (ef1) x Geb.schicht (ef570) 
                 Neubauten differenziert nach dem Aktualisierungsjahr (ef570=7) 
                 werden wegen kleinem Umfang nicht extra bercksichtigt, sondern
                 mit anderen Neubauten (ef570=6) zusammengefasst 
                 Neu ab 2005: Berichtsquartal */ 
   v570 = ef570;
   if (ef570>=6 & ef570<=7) then v570=6;
   schicht = ef12*1000 + ef1*10 + v570;

/* Klumpung: Auswahlbezirk
*  - fr die Daten bis einschlielich 2011 reicht EF3 zur Kennzeichnung aus - */
   idpsu = EF1*1000000 + EF3;

/* Auswahlsatz: Jahresdurchschnittsergebnisse */
   f = 0.01 * 0.70;

/* Designgewicht */
   d = 1/f;

/* Subpopulation: Bev. am Hauptwohns. (ef30), 15-64 Jahre (ef44) */
   sub = (ef30>=1 & ef30<=2 & ef44>=15 & ef44<=64);

/* ILO-Erwerbslos, Bev. am Hauptwohns., 15-64 Jahre */
   y = (ef29=2 & sub=1);
run;

/* === Designgewichtung ===
- Klumpung: idpsu Auswahlbezirksnr. (einstufige Zufallsauswahl).
- Schichtung: schicht = Berichtsquartal x Land x Gebudegr.klasse.
- Auswahlsatz (f): 0,7 % 
- Ziehen ohne Zurcklegen
- Designgewichtung: d = 1/f
Varianzschtzung aufgrund von Schichten mit einer PSU nicht mglich.
Betrifft in diesem Fall 5 Schichten der Gebudeschicht Gemeinschaftsunterkunft
mit insges. 36 Personen der Subpopulation, darunter sind keine Erwerbslosen (EF29=2). 
SAS lsst Schichten mit nur einer PSU bei der Schtzung unbercksichtigt.
*/
proc surveymeans data=temp RATE=0.007 sum ; 
   strata schicht;
   cluster idpsu;
   weight  d;
   domain  sub;
   class   sub;
   var     y;
run;
/* Ergebnis 
Gesamtwert:      1550429
Std.abweichung:    17341 */

* ----------------------------------------------------------------------------;

/* Beispiel 2: Schtzung des Gesamtwertes Zahl der Erwerbslosen mit 
               gebundener Hochrechnung (Regressionsschtzung)
*/
data temp;
 set mz.mz2015 (keep = ef1 ef3 ef4 ef5a ef5b ef12 ef29 ef30 ef31 ef44 ef46 ef117 ef369 ef371 ef570 ef952);
 * Fortlaufende Personennummer (Satznr. File);
 satznr = _n_ ;

/* Schichtung: Quartal (ef12) x Land (ef1) x Geb.schicht (ef570) 
               Neubauten differenziert nach dem Aktualisierungsjahr (ef570=7) 
               werden wegen kleinem Umfang nicht extra bercksichtigt, sondern
               mit anderen Neubauten (ef570=6) zusammengefasst 
               Neu ab 2005: Berichtsquartal */ 
   v570 = ef570;
   if (ef570>=6 & ef570<=7) then v570=6;
   schicht = ef12*1000 + ef1*10 + v570;
/* Klumpung: Auswahlbezirk
   - fr die Daten bis einschlielich 2011 reicht EF3 zur Kennzeichnung aus - */
   idpsu = EF1*1000000 + EF3;
/* Auswahlsatz: Jahresdurchschnittsergebnisse */
   f = 0.01 * 0.70;
/* Designgewicht */
   d = 1/f;
/* Hochrechnungsfaktor (gebundene Hochrechnung) Jahresdurchschnitt
   Beachte: EF952 ist im MZ ab 2006 bereits mit Faktor 1/0.7 multipliziert 
   Im Unterschied zu den Daten 2012 sind die Hochrechnungsfaktoren 2015
   fr die Haushaltsmitglieder konstant. */ 
   w = ef952 * 1000;
/* Korrekturfaktor */
   g = w/d; 
/* Subpopulation: Bev. am Hauptwohns. (ef30), 15-64 Jahre (ef44) */
   sub = (ef30>=1 & ef30<=2 & ef44>=15 & ef44<=64);
/* ILO-Erwerbslos, Bev. am Hauptwohns., 15-64 Jahre */
   y = (ef29=2 & sub=1);
run;

* Hilfsmerkmale zuspielen (erstellt mit xvar15.sas)  ;
data temp;
   merge temp mz.xvar15;
   by satznr;
run;

* Regression des interess. Merkmals auf Hilfsmerkmale 
     Residuum => Hilfsvariable fr Varianzschtzung ;
*   MZ 2005 - 2011: x1-x190;
*   MZ 2012 - 2015: x1-x224;
proc reg data=temp (keep = y x1-x224) ;
     model y = x1-x224 / noint;
	 output out=temp1 residual=e ;
run; 
quit;

data temp;
   merge temp temp1 (keep=e);
   * u gewichtetes Residuum, Hilfsvariable fr Designgewichtung;
   if e = . then e = 0;
   u = e * g;
run;

* Schtzung mit Hochrechnungsfaktor w (Zellgewichtung), Std.abw. irrelevant ;
proc surveymeans data = temp (keep = schicht idpsu w y sub e) RATE=0.007 SUM;
   strata  schicht;
   cluster idpsu;
   weight  w;
   domain  sub;
   class   sub;
   var     y;
run;

* Varianzschtzung mit Designgewicht d;
proc surveymeans data = temp (keep = schicht idpsu d sub u) RATE=0.007 SUM;
   strata  schicht;
   cluster idpsu;
   weight  d;
   domain  sub;
   class   sub;
   var u;
run;
/* Ergebnis 
Gesamtwert:      1944713
Std.abweichung:    19575  */

* ----------------------------------------------------------------------------;

/* Beispiel 3: Schtzung der Erwerbslosenquote mit Designgewichtung 
               Jahresdurchschnitt 
*/

data temp;
  set mz.mz2015 (keep = ef1 ef3 ef4 ef5a ef5b ef12 ef29 ef30 ef31 ef44 ef46 ef117 ef369 ef371 ef570 ef952);
  satznr = _n_ ;          /* Fortlaufende Personennummer (Satznr. File) */
  /* Schichtung: Quartal (ef12) x Land (ef1) x Geb.schicht (ef570) 
                 Neubauten differenziert nach dem Aktualisierungsjahr (ef570=7) 
                 werden wegen kleinem Umfang nicht extra bercksichtigt, sondern
                 mit anderen Neubauten (ef570=6) zusammengefasst 
                 Neu ab 2005: Berichtsquartal */ 
   v570 = ef570;
   if (ef570>=6 & ef570<=7) then v570=6;
   schicht = ef12*1000 + ef1*10 + v570;
/* Klumpung: Auswahlbezirk
*  - fr die Daten bis einschlielich 2011 reicht EF3 zur Kennzeichnung aus - */
   idpsu = EF1*1000000 + EF3;
/* Auswahlsatz: Jahresdurchschnittsergebnisse */
   f = 0.01 * 0.70;
/* Designgewicht */
   d = 1/f;
/* Subpopulation: Bev. am Hauptwohns. (ef30), 15-64 Jahre (ef44) */
   sub = (ef30>=1 & ef30<=2 & ef44>=15 & ef44<=64);
/* Zhler: ILO-Erwerbslos, Bev. am Hauptwohns., 15-64 Jahre */
   y = (ef29=2 & sub=1);
/* Nenner: ILO-Erwerbspersonen, Bev. am Hauptwohns., 15-64 Jahre */
   z = (ef29>=1 & ef29<=2) * sub;
run;

* Erwerbslosenquote  ;
proc surveymeans data = temp (keep = schicht idpsu d y z sub) R=0.007 MEAN CLSUM;
   strata  schicht;
   cluster idpsu;
   weight  d;
   ratio   y / z; 
   domain  sub; 
   class   sub;
run;
/* Ergebnis
Ratio:       0,045793
Std.fehler:  0,000493 */

* ----------------------------------------------------------------------------;

/* Beispiel 4: Schtzung der Erwerbslosenquote mittels Regressionsschtzung 
               Jahresdurchschnitt 
*/
data temp;
  set mz.mz2015 (keep = ef1 ef3 ef4 ef5a ef5b ef12 ef29 ef30 ef31 ef44 ef46 ef117 ef369 ef371 ef570 ef952);
  satznr = _n_ ; /* Fortlaufende Personennummer (Satznr. File) */
  /* Schichtung: Quartal (ef12) x Land (ef1) x Geb.schicht (ef570) 
                 Neubauten differenziert nach dem Aktualisierungsjahr (ef570=7) 
                 werden wegen kleinem Umfang nicht extra bercksichtigt, sondern
                 mit anderen Neubauten (ef570=6) zusammengefasst 
                 Neu ab 2005: Berichtsquartal */ 
   v570 = ef570;
   if (ef570>=6 & ef570<=7) then v570=6;
   schicht = ef12*1000 + ef1*10 + v570;
/* Klumpung: Auswahlbezirk
   - fr die Daten bis einschlielich 2011 reicht EF3 zur Kennzeichnung aus - */
   idpsu = EF1*1000000 + EF3;
/* Auswahlsatz: Jahresdurchschnittsergebnisse */
   f = 0.01 * 0.70;
/* Designgewicht */
   d = 1/f;
/* Hochrechnungsfaktor (gebundene Hochrechnung) Jahresdurchschnitt
   Beachte: ef952 ist im MZ ab 2006 bereits mit Faktor 1/0.7 multipliziert
   Im Unterschied zu den Daten 2012 sind die Hochrechnungsfaktoren 2015
   fr die Haushaltsmitglieder konstant. */ 
   w = ef952 * 1000;
/* Korrekturfaktor */
   g = w/d; 
/* Subpopulation: Bev. am Hauptwohns. (ef30), 15-64 Jahre (ef44) */
   sub = (ef30>=1 & ef30<=2 & ef44>=15 & ef44<=64);
/* Zhler: ILO-Erwerbslos, Bev. am Hauptwohns., 15-64 Jahre */
   y = (ef29=2 & sub=1);
/* Nenner: ILO-Erwerbspersonen, Bev. am Hauptwohns., 15-64 Jahre */
   z = (ef29>=1 & ef29<=2) * sub;
/* Gewichtete Zhler- und Nennermerkmale */
   wy = w*y;
   wz = w*z;
run;

* Hilfsmerkmale zuspielen (erstellt mit xvar15.sas)  ;
data temp;
   merge temp mz.xvar15;
   by satznr;
run;

* Gewichtete Gesamtwerte: Zhler- und Nennermerkmale bei gebundener Hochrechnung;
proc means data=temp (keep = wy wz) noprint ;
     output out=TYTZ (drop=_type_ _freq_ ) sum = ty tz ;   
run;

proc sql;	
	create table temp1
	as
	select *
	from temp, TYTZ
	where 1;
quit;

data  temp ;
  set temp1;
  * Gewichteter Anteils-/Verhltniswert bei gebundener Hochrechnung (Zellgewichtung): 
    Erwerbslosenquote ;
  R_yz = ty/tz ; 
  * linvar: Linearisierte (score) Variable fr Varianzschtzung;
  linvar = (y - R_yz * z) / tz;
run;

* MZ 2005 - 2011: x1-x190;
* MZ 2012 - 2015: x1-x224;
proc reg data=temp;
     model linvar = x1-x224 / noint;
	 output out=tempreg residual=e; /* Residuum */
run;  
quit;

data  tempreg ;
  set tempreg;
  u = e * g;  /* gewichtetes Residuum */
run;

* Schtzung der Erwerbslosenquote mit Hochrechnungsfaktor w, Std.abw. irrelevant;
proc surveymeans data = tempreg (keep = schicht idpsu w y z sub) R=0.007 MEAN CLSUM;
   strata  schicht;
   cluster idpsu;
   weight  w;
   ratio   y / z; 
run;

* Varianzschtzung mit Designgewicht ; 
proc surveymeans data  = tempreg  (keep = schicht idpsu d sub u) R=0.007 SUM ; 
   strata  schicht;
   cluster idpsu;
   weight  d;
   var     u ;
   domain  sub;
   class   sub;
run;
/* Ergebnis
Ratio:       0,04723
Std.fehler:  0,000454 */

