/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Diese Datei: xvar05.sas
     Dateiformat: Dos\Windows
     Zeichensatz: Windows-1252
     Download: 
     https://www.gesis.org/missy/files/documents/MZ/misc/TR_10-03_SAS.zip
SAS 9.4 for Windows 
Version: 10/2019

Konstruktion der Hilfsmerkmale fr Scientific Use File Mikrozensus 2005

Zusammenfhrung der Hilfsmerkmale mit SUF mittels Identifikator satznr

Siehe: 
Schimpl-Neimanns, Bernhard: Varianzschtzung fr Mikrozensus 
Scientific Use Files ab 2005. GESIS-Technical Report Nr. 2010/03. 
Mannheim: GESIS.
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2010/TechnicalReport_10-03.pdf
berarbeitete Fassung verffentlicht als:
Schimpl-Neimanns, Bernhard (2011): Schtzung des Stichprobenfehlers 
in Mikrozensus Scientific Use Files ab 2005, AStA Wirtschafts- und 
Sozialstatistisches Archiv 5 (1): 19-38. DOI: 10.1007/s11943-011-0092-4. 

Datenbeschreibung:
  https://www.gesis.org/missy/metadata/MZ/2005/

nderungen gegenber frherer Version:
* Syntax vereinfacht
* Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale bercksichtigt 
  nur Bevlkerung am Hauptwohnsitz
============================================================================= */  

* Lokales Arbeitsverzeichnis eintragen, z. B. 'c:\temp';
libname library 'Arbeitsverzeichnis' ;

* Lokales Datenverzeichnis eintragen;
libname mz 'Datenverzeichnis' ;

options NOFMTERR;

options compress = binary ;
RUN;

/* Beachte: Die Hilfsmerkmale werden lnderspezifisch gebildet. 
   Die Lnder sind im MZ 2005 und 2006 nach alphabetischer Sortierung, 
   ab MZ 2007 (wie bis 2004) gem amtlichem Gemeindeschlssel codiert.
                       Code im Mikrozensus SUF
   EF1 Bundesland       2005, 2006         2007
   --------------------------------------------
   Baden-Wrttemberg        01              08 
   (...)                                       
   Schleswig-Holstein       15              01
   Thringen                16              16
*/

/* Datendefinition */
data  tmp1;
  set mz.mz2005 (keep = EF1   /* Bundesland */
                        EF3   /* Nr. des Auswahlbezirks (laufend) */
                        EF4   /* Nr. des Haushalts im Auswahlbezirk (laufend) */
                        EF5   /* Nr. der Person im Haushalt (laufend) */
                        EF12  /* Berichtsquartal */
                        EF29  /* Erwerbstyp  */
                        EF30  /* Bevlkerung: Haupt- oder Nebenwohnsitz */
                        EF31  /* Bevlkerung: Privathaushalte */
                        EF44  /* Alter */
                        EF46  /* Geschlecht */
                        EF117 /* Stellung im Beruf */
                        EF369 /* 1. Staatsangehrigkeit */
                        EF371 /* Staatsangehrigkeit typisiert */
                        EF570 /* Gebudegrenklassen */
                        EF952 /* Hochrechnungsfaktor: Jahr */ );
  * Fortlaufende Personennummer (Satznr. File);
  satznr = _n_ ;
  * ef5: Pers.Nr. -> 0 wenn Bev. in Priv.HH;
  v5 = ef5*(ef31=2);
  * hhid: vorl. HH-Nr., extra fr Pers. in Gem.Unterk. (ef31=2);
  hhid = ef3*10000 + ef4*100 + v5;  
run;

proc sort data = tmp1; 
     by hhid; 
run;

data tmp1;
  set tmp1;
  pnr + 1;  /* Personennummer im HH (:= ef3 x ef4) */
  by hhid;
  if first.hhid then pnr = 1;
run;

/* Vorlufige fortlaufende Haushaltsnummer bilden .
   Im MZ 2005 ist bei der Konstruktion der Haushaltsnummer (EF4) das 
   Berichtsquartal (EF12) bercksichtigt, sodass auf die Verwendung 
   von EF12 bei der folgenden Haushaltsabgrenzung verzichtet werden
   kann. 
   Abweichend davon variiert EF12 Berichtsquartal in 4 Haushalten. Um 
   weitere Angaben zu Haushaltszusammenhngen nicht zu stren und
   aufgrund der geringen Zahl von Datenproblemen, wird EF12 im Folgenden
   nicht bercksichtigt.
*/
data tmp2;
  set tmp1;
  where (pnr=1);
  hhnr = _n_; /* fortlfd. Haushaltsnr. extra fr Pers. in Gem.Unterk. */ 
run;

data tmp3;
  merge tmp1 tmp2;
  by hhid;
run;

proc sort data = tmp3; 
     by satznr; 
run;


/* === Abgrenzung der Hilfsmerkmale === 
 Siehe bersicht 3: Realisiertes Hochrechnungsmodell nach Bundeslndern
 im 2. Vierteljahr 2005, S. 1046 in: Afentakis, A. & Bihler, W. (2005): 
 Das Hochrechnungsverfahren beim unterjhrigen Mikrozensus ab 2005, 
 Wirtschaft und Statistik 10/2005, 1039-1048.

Hochrechnungsterme: .
H1: Land x Bevlkerung insgesamt je Monat
H2: Land x Geschlecht (m, w) x Alter (<15, 15 bis 44, 45+ Jahre)
H3: Land x Staatsangehrigk. (D, TR, EU25, nEU) x Geschlecht (m, w)
H4: Land x Bevlkerungstyp (Zeit- und Berufssoldaten einschl. ...)
*/
data tmp3;
     set tmp3;
 sex = (ef46=2); /* ef46 Geschlecht -> sex: 1->0 mnnlich, 2->1 weiblich */
 age =   1*(ef44>=0  & ef44<=14)  /* ef44 Alter -> age: 0-14 Jahre -> 1 */
       + 2*(ef44>=45 & ef44<=95); /* 15-44 Jahre -> 0, 45-95 Jahre -> 2 */
 nat =   1*(ef371=3 & ef369=34) /* Staatsangeh.: 0=Deutsch, 1=Trkei */
       + 2*(ef371=2) /* 2=EU-Auslnder */
       + 3*(ef371=3 & ef369 ne 34); /* 3=nicht EU-Auslnder */
 zsw =   1*(ef117=9) /* Bevlkerungsgruppe 0= Zivilbev., 1=Soldaten */
       + 2*(ef117=10); /* 2=Wehrdienstleistende */
 * Fr Lnder mit Hochrechnungstermen H1 bis H4 ;
 x1  = 1 ;                 /* H1: Konstante [m, Alter=15-44, Zivilbev.] */
 x2  = (sex=1);            /* H2: Geschlecht=w */
 x3  = (age=1);            /* H2: Alter=<15 */
 x4  = (age=2);            /* H2: Alter=45+ */
 x5  = (sex=1) * (age=1);  /* H2: Geschlecht=w x Alter=<15 */
 x6  = (sex=1) * (age=2);  /* H2: Geschlecht=w x Alter=45+ */
 x7  = (nat=1);            /* H3: Staatsang.=TR */
 x8  = (nat=2);            /* H3: Staatsang.=EU */
 x9  = (nat=3);            /* H3: Staatsang.=SO */
 x10 = (nat=1) * (sex=1);  /* H3: Staatsang.=TR x Geschlecht=w */
 x11 = (nat=2) * (sex=1);  /* H3: Staatsang.=EU x Geschlecht=w */
 x12 = (nat=3) * (sex=1);  /* H3: Staatsang.=SO x Geschlecht=w */
 x13 = (zsw=1);            /* H4: Bevlk.gr=Soldaten */
 x14 = (zsw=2);            /* H4: Bevlk.gr=Wehrpfl */
/* Reduziertes Hochrechnungsmodell H3 
   R2: Staatsangehrigkeit (deutsch, nicht deutsch) x Geschlecht
   Fr Lnder: Brandenburg, Mecklenburg-Vorpommern, Sachsen, 
                 Sachsen-Anhalt, Thringen */
 xn  = (nat>0);            /* x7  - x9  */
 xng = (nat>0) * (sex=1);  /* x10 - x12 */
* Hilfsmerkmale lnderweise zunchst auf Personenebene bilden 
  Hilfsmerkmale sind nur fr Bevlkerung am Hauptwohnsitz (ef30<3) definiert;
* === Baden-Wrttemberg (ef1=1);
 array q1{14} x1-x14;
 array z1{14} x15-x28;
 do i = 1 to 14;
   z1{i} = q1{i}*(ef1=1)*(ef30<3); 
 end;
* === Bayern (ef1=2);
 array q2{14} x1-x14;
 array z2{14} x29-x42;
 do i = 1 to 14;
   z2{i} = q2{i}*(ef1=2)*(ef30<3); 
 end;
* === Berlin (ef1=3);
 array q3{14} x1-x14;
 array z3{14} x43-x56;
 do i = 1 to 14;
   z3{i} = q3{i}*(ef1=3)*(ef30<3); 
 end;
* === Hessen (ef1=7);
 array q7{14} x1-x14;
 array z7{14} x57-x70;
 do i = 1 to 14;
   z7{i} = q7{i}*(ef1=7)*(ef30<3); 
 end;
* ===Niedersachsen (ef1=9);
 array q9{14} x1-x14;
 array z9{14} x71-x84;
 do i = 1 to 14;
   z9{i} = q9{i}*(ef1=9)*(ef30<3); 
 end;
* === Rheinland-Pfalz (ef1=11);
 array q11{14} x1-x14;
 array z11{14} x85-x98;
 do i = 1 to 14;
   z11{i} = q11{i}*(ef1=11)*(ef30<3); 
 end;
* === Schleswig-Holstein (ef1=15);
 array q15{14} x1-x14;
 array z15{14} x99-x112;
 do i = 1 to 14;
   z15{i} = q15{i}*(ef1=15)*(ef30<3); 
 end;
* === Nordrhein-Westfalen (ef1=10): siehe unten ;
* Reduziertes Hochrechnungsmodell H3 ;
* === Brandenburg (ef1=4); 
 array q4{10} x1-x6 xn xng x13 x14;
 array z4{10} x113-x122;
 do i = 1 to 10;
   z4{i} = q4{i}*(ef1=4)*(ef30<3); 
 end;
* === Mecklenburg-Vorpommern (ef1=8);
 array q8{10} x1-x6 xn xng x13 x14;
 array z8{10} x123-x132;
 do i = 1 to 10;
   z8{i} = q8{i}*(ef1=8)*(ef30<3); 
 end;
* === Sachsen (ef1=13);
 array q13{10} x1-x6 xn xng x13 x14;
 array z13{10} x133-x142;
 do i = 1 to 10;
   z13{i} = q13{i}*(ef1=13)*(ef30<3); 
 end;
* === Sachsen-Anhalt (ef1=14);
 array q14{10} x1-x6 xn xng x13 x14;
 array z14{10} x143-x152;
 do i = 1 to 10;
   z14{i} = q14{i}*(ef1=14)*(ef30<3); 
 end;
* === Thringen (ef1=16);
 array q16{10} x1-x6 xn xng x13 x14;
 array z16{10} x153-x162;
 do i = 1 to 10;
   z16{i} = q16{i}*(ef1=16)*(ef30<3); 
 end;
* Reduziertes Hochrechnungsmodell H3, H4
    R1, R2: Ohne Unterscheidung nach Bevlkerungstyp ;
* === Bremen (ef1=5);
 array q5{8} x1-x6 xn xng;
 array z5{8} x163-x170;
 do i = 1 to 8;
   z5{i} = q5{i}*(ef1=5)*(ef30<3); 
 end;
* === Hamburg (ef1=6);
 array q6{8} x1-x6 xn xng;
 array z6{8} x171-x178;
 do i = 1 to 8;
   z6{i} = q6{i}*(ef1=6)*(ef30<3); 
 end;
* Reduziertes Hochrechnungsmodell H4
  Fr Saarland: ohne Unterscheidung nach Bevlkerungstyp, aber 
  R1: Staatsangehrigkeit (D, TR, EU25, nEU25);
* === Saarland (ef1=12);
 array q12{12} x1-x12;
 array z12{12} x179-x190;
 do i = 1 to 12;
   z12{i} = q12{i}*(ef1=12)*(ef30<3); 
 end;
* === Nordrhein-Westfalen (ef1=10);
 array q10{14} x1-x14;
 do i = 1 to 14;
   q10{i} = q10{i}*(ef1=10)*(ef30<3); 
 end;

* Bevlkerung am Hauptwohnsitz;
 bevhws = (ef30>=1 & ef30<=2);

run;

proc sort data = tmp3; 
     by hhnr; 
run;

* Arithm. Mittelwerte der Hilfsmerkmale auf Haushaltsebene bilden: x*
* hhgr: Anzahl der Personen am Hauptwohnsitz pro hhnr, incl. Gemeinsch.unterk.;
* x* : Summe der Hilfsmerkmale auf Haushaltsebene, incl. Gemeinsch.unterk.;
proc means data=tmp3 noprint ;
     var bevhws x1-x190 ;
     * class hhnr;
     by hhnr;   
     output out=tmp4 (drop=_type_ _freq_ ) sum = hhgr x1-x190 ;
run;

data tmp4 ;
  set tmp4; 
  * Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale 
  *   (Bevlkerung am Hauptwohnsitz) ;
  array q11{190} x1-x190;
    do i = 1 to 190;
      if hhgr NE 0 then q11{i} = q11{i} / hhgr;
      if hhgr EQ 0 then q11{i} = 0; 
    end;
run;

data tmp5;
  merge tmp3 (drop = bevhws x1-x190) tmp4;
  by hhnr;
run;


data mz.xvar05 (keep=hhnr satznr x1-x190);
  set tmp5;
  array q12{190} x1-x190;
    do i = 1 to 190;
      if EF30>=1 & EF30<=2 then q12{i} = q12{i};
      if EF30<1 | EF30>2   then q12{i} = 0; 
    end;
run;

proc sort data = mz.xvar05;
     by satznr; 
run;
