/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
Diese Datei: xvar11.sas
     Dateiformat: Dos\Windows
     Zeichensatz: Windows-1252
     Download: 
     https://www.gesis.org/missy/files/documents/MZ/misc/TR_10-03_SAS.zip
Version: 10/2019
SAS 9.4 for Windows 

Konstruktion der Hilfsmerkmale fr Scientific Use File Mikrozensus 2011
Datenbeschreibung:
  https://www.gesis.org/missy/metadata/MZ/2011/

Zusammenfhrung der Hilfsmerkmale mit SUF mittels Identifikator satznr

Siehe: 
Schimpl-Neimanns, Bernhard: Varianzschtzung fr Mikrozensus 
Scientific Use Files ab 2005. GESIS-Technical Report Nr. 2010/03. 
Mannheim: GESIS.
  URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
       gesis_reihen/gesis_methodenberichte/2010/TechnicalReport_10-03.pdf
berarbeitete Fassung verffentlicht als:
Schimpl-Neimanns, Bernhard (2011): Schtzung des Stichprobenfehlers 
in Mikrozensus Scientific Use Files ab 2005, AStA Wirtschafts- und 
Sozialstatistisches Archiv 5 (1): 19-38. DOI: 10.1007/s11943-011-0092-4. 

nderungen gegenber frherer Version:
* Syntax vereinfacht
* Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale bercksichtigt 
  nur Bevlkerung am Hauptwohnsitz
============================================================================= */  

* Lokales Arbeitsverzeichnis eintragen, z. B. 'c:\temp';
libname library 'Arbeitsverzeichnis' ;

* Lokales Datenverzeichnis eintragen;
libname mz 'Datenverzeichnis' ;

options compress = binary ;

/* Beachte: Die Hilfsmerkmale werden lnderspezifisch gebildet. 
   Die Lnder sind im MZ 2005 und 2006 nach alphabetischer Sortierung, 
   ab MZ 2007 (wie bis 2004) gem amtlichem Gemeindeschlssel codiert.
                       Code im Mikrozensus SUF
   EF1 Bundesland       2005, 2006         2007
   --------------------------------------------
   Baden-Wrttemberg        01              08 
   (...)                                       
   Schleswig-Holstein       15              01
   Thringen                16              16
*/

/* Datendefinition: Mikrozensus 2011 Scientific Use File "mz2011", ggf. ndern */
data temp;
	retain satznr EF1 EF3 EF4 EF5a EF5b EF12 pnrGU satznr;
	set mz.mz2011 (keep = EF1 EF3 EF4 EF5a EF5b EF12 EF30 EF31 EF44 EF46 EF117 EF369 EF371);
 
	satznr = _n_;   /* Satznummer der Ausgangsdaten fr spteres Zusammenfhren mit MZ 2011 */
	pnrGU = EF5a*(ef31=2); /* EF5a Pers.Nr. im HH -> 0 wenn Bev. in Priv.HH */
run;

proc sort data = temp; 
     by EF1 EF3 EF4 EF5b EF12 pnrGU satznr;
run;

data temp;
  retain satznr EF1 EF3 EF4 EF5b EF12 pnrGU pnr;
  set temp;
  pnr + 1;  /* Neue fortlfd. Personennummer im HH (Pers. in GU := HH) */
  by EF1 EF3 EF4 EF5b EF12 pnrGU;
  if first.EF1 | first.EF3 | first.EF4 | first.EF5b | first.EF12 | first.pnrGU then pnr = 1;
run;

/* Vorlufige fortlaufende Haushaltsnummer
    Variablen, die zur Abgrenzung eines Haushalts erforderlich sind; siehe
    https://www.gesis.org/missy/materials/MZ/tools/abgrenzungerhebungseinheiten
    EF1   Bundesland
    EF3   Nr. des Auswahlbezirks
    EF12  Berichtsquartal
    EF4R  Nr. des Haushalts im Auswahlbezirk (systemfrei) - plausibilisiert

Neue Haushaltsnummer
    Pers. in Gemeinschaftsunterkuenften bilden einen eigenen "Haushalt"
*/
data temp1 (keep = EF1 EF3 EF4 EF5b EF12 pnrGU hhnr);
  set temp (keep = EF1 EF3 EF4 EF5b EF12 pnrGU pnr);
  where (pnr=1);
  hhnr = _n_; /* fortlfd. Haushaltsnr. extra fr Pers. in Gem.Unterk. */ 
run;

proc sort data = temp1; 
     by EF1 EF3 EF4 EF5b EF12 pnrGU; 
run;

data temp;
  merge temp1 temp;
  by EF1 EF3 EF4 EF5b EF12 pnrGU;
run;

proc sort data = temp; 
     by satznr; 
run;

/* === Abgrenzung der Hilfsmerkmale === 
Siehe bersicht 3: Realisiertes Hochrechnungsmodell nach Bundeslndern
im 2. Vierteljahr 2005, S. 1046 in: Afentakis, A. & Bihler, W. (2005): 
Das Hochrechnungsverfahren beim unterjhrigen Mikrozensus ab 2005, 
Wirtschaft und Statistik 10/2005, 1039-1048.

Hochrechnungsterme:
H1: Land x Bevlkerung insgesamt je Monat
H2: Land x Geschlecht (m, w) x Alter (<15, 15 bis 44, 45+ Jahre)
H3: Land x Staatsangehrigk. (D, TR, EU25, nEU) x Geschlecht (m, w)
H4: Land x Bevlkerungstyp (Zeit- und Berufssoldaten einschl. ...)
*/
data temp;
     set temp;
 sex = (ef46=2); /* ef46 Geschlecht -> sex: 1->0 mnnlich, 2->1 weiblich */
 age =   1*(ef44>=0  & ef44<=14)  /* ef44 Alter -> age: 0-14 Jahre -> 1 */
       + 2*(ef44>=45 & ef44<=95); /* 15-44 Jahre -> 0, 45-95 Jahre -> 2 */
 nat =   1*(ef371=3 & ef369=163)  /* Staatsangeh.: 0=Deutsch, 1=Trkei - neuer Code ab MZ 2010 163 */
       + 2*(ef371=2) /* 2=EU-Auslnder */
       + 3*(ef371=3 & ef369 ne 163); /* 3=nicht EU-Auslnder */
 zsw =   1*(ef117=9) /* Bevlkerungsgruppe 0= Zivilbev., 1=Soldaten */
       + 2*(ef117=10); /* 2=Wehrdienstleistende */
 * Fr Lnder mit Hochrechnungstermen H1 bis H4 ;
 x1  = 1 ;                 /* H1: Konstante [m, Alter=15-44, Zivilbev.] */
 x2  = (sex=1);            /* H2: Geschlecht=w */
 x3  = (age=1);            /* H2: Alter=<15 */
 x4  = (age=2);            /* H2: Alter=45+ */
 x5  = (sex=1) * (age=1);  /* H2: Geschlecht=w x Alter=<15 */
 x6  = (sex=1) * (age=2);  /* H2: Geschlecht=w x Alter=45+ */
 x7  = (nat=1);            /* H3: Staatsang.=TR */
 x8  = (nat=2);            /* H3: Staatsang.=EU */
 x9  = (nat=3);            /* H3: Staatsang.=SO */
 x10 = (nat=1) * (sex=1);  /* H3: Staatsang.=TR x Geschlecht=w */
 x11 = (nat=2) * (sex=1);  /* H3: Staatsang.=EU x Geschlecht=w */
 x12 = (nat=3) * (sex=1);  /* H3: Staatsang.=SO x Geschlecht=w */
 x13 = (zsw=1);            /* H4: Bevlk.gr=Soldaten */
 x14 = (zsw=2);            /* H4: Bevlk.gr=Wehrpfl */
/* Reduziertes Hochrechnungsmodell H3 
   R2: Staatsangehrigkeit (deutsch, nicht deutsch) x Geschlecht
   Fr Lnder: Brandenburg, Mecklenburg-Vorpommern, Sachsen, 
                 Sachsen-Anhalt, Thringen */
 xn  = (nat>0);            /* x7  - x9  */
 xng = (nat>0) * (sex=1);  /* x10 - x12 */
* Hilfsmerkmale lnderweise zunchst auf Personenebene bilden 
  Hilfsmerkmale sind nur fr Bevlkerung am Hauptwohnsitz (ef30<3) definiert;
* === Baden-Wrttemberg BW (ef1=8);
 array q1{14} x1-x14;
 array z1{14} x15-x28;
 do i = 1 to 14;
   z1{i} = q1{i}*(ef1=8)*(ef30<3); 
 end;
* === Bayern BY (ef1=9);
 array q2{14} x1-x14;
 array z2{14} x29-x42;
 do i = 1 to 14;
   z2{i} = q2{i}*(ef1=9)*(ef30<3); 
 end;
* === Berlin BE (ef1=11);
 array q3{14} x1-x14;
 array z3{14} x43-x56;
 do i = 1 to 14;
   z3{i} = q3{i}*(ef1=11)*(ef30<3); 
 end;
* === Hessen HE (ef1=6);
 array q7{14} x1-x14;
 array z7{14} x57-x70;
 do i = 1 to 14;
   z7{i} = q7{i}*(ef1=6)*(ef30<3); 
 end;
* ===Niedersachsen NI (ef1=3);
 array q9{14} x1-x14;
 array z9{14} x71-x84;
 do i = 1 to 14;
   z9{i} = q9{i}*(ef1=3)*(ef30<3); 
 end;
* === Rheinland-Pfalz RP (ef1=7);
 array q11{14} x1-x14;
 array z11{14} x85-x98;
 do i = 1 to 14;
   z11{i} = q11{i}*(ef1=7)*(ef30<3); 
 end;
* === Schleswig-Holstein SH (ef1=1);
 array q15{14} x1-x14;
 array z15{14} x99-x112;
 do i = 1 to 14;
   z15{i} = q15{i}*(ef1=1)*(ef30<3); 
 end;
* === Nordrhein-Westfalen NW (ef1=5): siehe unten ;
* Reduziertes Hochrechnungsmodell H3 ;
* === Brandenburg (ef1=12); 
 array q4{10} x1-x6 xn xng x13 x14;
 array z4{10} x113-x122;
 do i = 1 to 10;
   z4{i} = q4{i}*(ef1=12)*(ef30<3); 
 end;
* === Mecklenburg-Vorpommern MV (ef1=13);
 array q8{10} x1-x6 xn xng x13 x14;
 array z8{10} x123-x132;
 do i = 1 to 10;
   z8{i} = q8{i}*(ef1=13)*(ef30<3); 
 end;
* === Sachsen SN (ef1=14);
 array q13{10} x1-x6 xn xng x13 x14;
 array z13{10} x133-x142;
 do i = 1 to 10;
   z13{i} = q13{i}*(ef1=14)*(ef30<3); 
 end;
* === Sachsen-Anhalt ST (ef1=15);
 array q14{10} x1-x6 xn xng x13 x14;
 array z14{10} x143-x152;
 do i = 1 to 10;
   z14{i} = q14{i}*(ef1=15)*(ef30<3); 
 end;
* === Thringen TH (ef1=16);
 array q16{10} x1-x6 xn xng x13 x14;
 array z16{10} x153-x162;
 do i = 1 to 10;
   z16{i} = q16{i}*(ef1=16)*(ef30<3); 
 end;
* Reduziertes Hochrechnungsmodell H3, H4
    R1, R2: Ohne Unterscheidung nach Bevlkerungstyp ;
* === Bremen HB (ef1=4);
 array q5{8} x1-x6 xn xng;
 array z5{8} x163-x170;
 do i = 1 to 8;
   z5{i} = q5{i}*(ef1=4)*(ef30<3); 
 end;
* === Hamburg HH (ef1=2);
 array q6{8} x1-x6 xn xng;
 array z6{8} x171-x178;
 do i = 1 to 8;
   z6{i} = q6{i}*(ef1=2)*(ef30<3); 
 end;
* Reduziertes Hochrechnungsmodell H4
  Fr Saarland: ohne Unterscheidung nach Bevlkerungstyp, aber 
  R1: Staatsangehrigkeit (D, TR, EU25, nEU25);
* === Saarland SL (ef1=10);
 array q12{12} x1-x12;
 array z12{12} x179-x190;
 do i = 1 to 12;
   z12{i} = q12{i}*(ef1=10)*(ef30<3); 
 end;
* === Nordrhein-Westfalen NW (ef1=5);
 array q10{14} x1-x14;
 do i = 1 to 14;
   q10{i} = q10{i}*(ef1=5)*(ef30<3); 
 end;
* Bevlkerung am Hauptwohnsitz;
 bevhws = (ef30>=1 & ef30<=2);
run;

proc sort data = temp; 
     by hhnr; 
run;

* Arithm. Mittelwerte der Hilfsmerkmale auf Haushaltsebene bilden: x*;
* hhgr: Anzahl der Personen am Hauptwohnsitz pro hhnr, incl. Gemeinsch.unterk.;
* x* : Summe der Hilfsmerkmale auf Haushaltsebene, incl. Gemeinsch.unterk.;
proc means data=temp noprint ;
     var bevhws x1-x190 ;
     * class hhnr;
     by hhnr;   
     output out=tmp (drop=_type_ _freq_ ) sum = hhgr x1-x190 ;
run;

data tmp ;
  set tmp; 
  * Berechnung der Mittelwerte der Indikatoren der Hilfsmerkmale 
  *   (Bevlkerung am Hauptwohnsitz) ;
  array q11{190} x1-x190;
    do i = 1 to 190;
      if hhgr NE 0 then q11{i} = q11{i} / hhgr;
      if hhgr EQ 0 then q11{i} = 0; 
    end;
run;

data tmp;
  merge temp (drop = bevhws x1-x190) tmp;
  by hhnr;
run;

data mz.xvar11 (keep=hhnr satznr x1-x190);   
  set tmp;
  array q12{190} x1-x190;
    do i = 1 to 190;
      if EF30>=1 & EF30<=2 then q12{i} = q12{i};
      if EF30<1 | EF30>2   then q12{i} = 0; 
    end;
run;

proc sort data = mz.xvar11;
     by satznr; 
run;
